[llvm-commits] [llvm] r124324 - /llvm/trunk/utils/TableGen/AsmMatcherEmitter.cpp

Bob Wilson bob.wilson at apple.com
Wed Jan 26 13:26:21 PST 2011


Author: bwilson
Date: Wed Jan 26 15:26:21 2011
New Revision: 124324

URL: http://llvm.org/viewvc/llvm-project?rev=124324&view=rev
Log:
Fix spelling of CouldMatchAmbiguouslyWith method name.

Modified:
    llvm/trunk/utils/TableGen/AsmMatcherEmitter.cpp

Modified: llvm/trunk/utils/TableGen/AsmMatcherEmitter.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/utils/TableGen/AsmMatcherEmitter.cpp?rev=124324&r1=124323&r2=124324&view=diff
==============================================================================
--- llvm/trunk/utils/TableGen/AsmMatcherEmitter.cpp (original)
+++ llvm/trunk/utils/TableGen/AsmMatcherEmitter.cpp Wed Jan 26 15:26:21 2011
@@ -426,7 +426,7 @@
       return AsmOperands.size() < RHS.AsmOperands.size();
 
     // Compare lexicographically by operand. The matcher validates that other
     // orderings wouldn't be ambiguous using \see CouldMatchAmiguouslyWith().
     for (unsigned i = 0, e = AsmOperands.size(); i != e; ++i) {
       if (*AsmOperands[i].Class < *RHS.AsmOperands[i].Class)
         return true;
@@ -437,10 +437,10 @@
     return false;
   }
 
   /// CouldMatchAmiguouslyWith - Check whether this matchable could
   /// ambiguously match the same set of operands as \arg RHS (without being a
   /// strictly superior match).
-  bool CouldMatchAmiguouslyWith(const MatchableInfo &RHS) {
+  bool CouldMatchAmbiguouslyWith(const MatchableInfo &RHS) {
     // The primary comparator is the instruction mnemonic.
     if (Mnemonic != RHS.Mnemonic)
       return false;
@@ -1867,7 +1867,7 @@
         MatchableInfo &A = *Info.Matchables[i];
         MatchableInfo &B = *Info.Matchables[j];
 
-        if (A.CouldMatchAmiguouslyWith(B)) {
+        if (A.CouldMatchAmbiguouslyWith(B)) {
           errs() << "warning: ambiguous matchables:\n";
           A.dump();
           errs() << "\nis incomparable with:\n";
@@ -426,7 +426,7 @@
 
     // Compare lexicographically by operand. The matcher validates that other
-    // orderings wouldn't be ambiguous using \see CouldMatchAmiguouslyWith().
+    // orderings wouldn't be ambiguous using \see CouldMatchAmbiguouslyWith().
     for (unsigned i = 0, e = AsmOperands.size(); i != e; ++i) {
       if (*AsmOperands[i].Class < *RHS.AsmOperands[i].Class)
@@ -437,10 +437,10 @@
   }
 
-  /// CouldMatchAmiguouslyWith - Check whether this matchable could
+  /// CouldMatchAmbiguouslyWith - Check whether this matchable could
   /// ambiguously match the same set of operands as \arg RHS (without being a
   /// strictly superior match).





More information about the llvm-commits mailing list